@@ -273,6 +273,8 @@ var _ = Describe("Functional", func() {
 						cmd := exec.Command(binary, "read", "kafka",
 							"--address", kafkaAddress,
 							"--topics", kafkaTopic,
+							"--read-offset", "0",
+							"--use-consumer-group=false",
 						)
 
 						readOut, err := cmd.CombinedOutput()
@@ -351,6 +353,8 @@ var _ = Describe("Functional", func() {
 						"--decode-type", "thrift",
 						"--thrift-struct", "sh.batch.schema.Account",
 						"--thrift-dirs", "test-assets/thrift/schema/",
+						"--read-offset", "0",
+						"--use-consumer-group=false",
 					)
 
 					readOutput, err := readCmd.CombinedOutput()
@@ -402,6 +406,8 @@ var _ = Describe("Functional", func() {
 						"--decode-type", "protobuf",
 						"--protobuf-root-message", "sample.Envelope",
 						"--protobuf-descriptor-set", "./test-assets/protobuf-any/sample/protos.fds",
+						"--read-offset", "0",
+						"--use-consumer-group=false",
 					)
 
 					readOutput, err := readCmd.CombinedOutput()
@@ -452,6 +458,8 @@ var _ = Describe("Functional", func() {
 						"--protobuf-envelope-type", "shallow",
 						"--shallow-envelope-field-number", "2",
 						"--shallow-envelope-message", "shallow.Payload",
+						"--read-offset", "0",
+						"--use-consumer-group=false",
 					)
 
 					readOutput, err := readCmd.CombinedOutput()
@@ -2243,7 +2251,8 @@ var _ = Describe("Functional", func() {
 						"create",
 						"relay",
 						"kafka",
-						"--batchsh-grpc-address", "grpc-collector.dev.batch.sh:443",
+						"--manage-token", "streamdal",
+						"--streamdal-grpc-address", "grpc-collector.dev.streamdal.com:443",
 						"--connection-id", connId,
 						"--collection-token", testCollectionToken,
 						"--topics", "foo",
@@ -2274,6 +2283,7 @@ var _ = Describe("Functional", func() {
 						"manage",
 						"get",
 						"relay",
+						"--manage-token", "streamdal",
 						"--id", relayId,
 					)
 					out, err := getRelayCmd.CombinedOutput()
@@ -2295,6 +2305,7 @@ var _ = Describe("Functional", func() {
 						"manage",
 						"stop",
 						"relay",
+						"--manage-token", "streamdal",
 						"--id", relayId,
 					)
 					out, err := stopRelayCmd.CombinedOutput()
@@ -2313,6 +2324,7 @@ var _ = Describe("Functional", func() {
 						"manage",
 						"resume",
 						"relay",
+						"--manage-token", "streamdal",
 						"--id", relayId,
 					)
 					out, err := resumeRelayCmd.CombinedOutput()
@@ -2331,6 +2343,7 @@ var _ = Describe("Functional", func() {
 						"manage",
 						"delete",
 						"relay",
+						"--manage-token", "streamdal",
 						"--id", relayId,
 					)
 					out, err := deleteRelayCmd.CombinedOutput()
@@ -2368,7 +2381,8 @@ var _ = Describe("Functional", func() {
 						"create",
 						"tunnel",
 						"kafka",
-						"--x-tunnel-address", "dproxy.dev.batch.sh:443",
+						"--manage-token", "streamdal",
+						"--x-tunnel-address", "dproxy.dev.streamdal.com:443",
 						"--connection-id", connId,
 						"--tunnel-token", batchAPIToken,
 						"--topics", "foo",
@@ -2399,6 +2413,7 @@ var _ = Describe("Functional", func() {
 						"manage",
 						"get",
 						"tunnel",
+						"--manage-token", "streamdal",
 						"--id", tunnelId,
 					)
 					out, err := getTunnelCmd.CombinedOutput()
@@ -2420,6 +2435,7 @@ var _ = Describe("Functional", func() {
 						"manage",
 						"stop",
 						"tunnel",
+						"--manage-token", "streamdal",
 						"--id", tunnelId,
 					)
 					out, err := stopTunnelCmd.CombinedOutput()
@@ -2438,6 +2454,7 @@ var _ = Describe("Functional", func() {
 						"manage",
 						"resume",
 						"tunnel",
+						"--manage-token", "streamdal",
 						"--id", tunnelId,
 					)
 					out, err := resumeTunnelCmd.CombinedOutput()
@@ -2456,6 +2473,7 @@ var _ = Describe("Functional", func() {
 						"manage",
 						"delete",
 						"tunnel",
+						"--manage-token", "streamdal",
 						"--id", tunnelId,
 					)
 					out, err := deleteTunnelCmd.CombinedOutput()
@@ -2506,7 +2524,8 @@ var _ = Describe("Functional", func() {
 						"create",
 						"relay",
 						"rabbit",
-						"--batchsh-grpc-address", "grpc-collector.dev.batch.sh:443",
+						"--manage-token", "streamdal",
+						"--streamdal-grpc-address", "grpc-collector.dev.streamdal.com:443",
 						"--connection-id", connId,
 						"--collection-token", testCollectionToken,
 						"--exchange-name", exchangeName,
@@ -2539,6 +2558,7 @@ var _ = Describe("Functional", func() {
 						"manage",
 						"get",
 						"relay",
+						"--manage-token", "streamdal",
 						"--id", relayId,
 					)
 					out, err := getRelayCmd.CombinedOutput()
@@ -2560,6 +2580,7 @@ var _ = Describe("Functional", func() {
 						"manage",
 						"stop",
 						"relay",
+						"--manage-token", "streamdal",
 						"--id", relayId,
 					)
 					out, err := stopRelayCmd.CombinedOutput()
@@ -2578,6 +2599,7 @@ var _ = Describe("Functional", func() {
 						"manage",
 						"resume",
 						"relay",
+						"--manage-token", "streamdal",
 						"--id", relayId,
 					)
 					out, err := resumeRelayCmd.CombinedOutput()
@@ -2596,6 +2618,7 @@ var _ = Describe("Functional", func() {
 						"manage",
 						"delete",
 						"relay",
+						"--manage-token", "streamdal",
 						"--id", relayId,
 					)
 					out, err := deleteRelayCmd.CombinedOutput()
@@ -2643,7 +2666,8 @@ var _ = Describe("Functional", func() {
 						"create",
 						"tunnel",
 						"rabbit",
-						"--x-tunnel-address", "dproxy.dev.batch.sh:443",
+						"--manage-token", "streamdal",
+						"--x-tunnel-address", "dproxy.dev.streamdal.com:443",
 						"--connection-id", connId,
 						"--tunnel-token", batchAPIToken,
 						"--exchange-name", exchangeName,
@@ -2675,6 +2699,7 @@ var _ = Describe("Functional", func() {
 						"manage",
 						"get",
 						"tunnel",
+						"--manage-token", "streamdal",
 						"--id", tunnelId,
 					)
 					out, err := getTunnelCmd.CombinedOutput()
@@ -2696,6 +2721,7 @@ var _ = Describe("Functional", func() {
 						"manage",
 						"stop",
 						"tunnel",
+						"--manage-token", "streamdal",
 						"--id", tunnelId,
 					)
 					out, err := stopTunnelCmd.CombinedOutput()
@@ -2714,6 +2740,7 @@ var _ = Describe("Functional", func() {
 						"manage",
 						"resume",
 						"tunnel",
+						"--manage-token", "streamdal",
 						"--id", tunnelId,
 					)
 					out, err := resumeTunnelCmd.CombinedOutput()
@@ -2732,6 +2759,7 @@ var _ = Describe("Functional", func() {
 						"manage",
 						"delete",
 						"tunnel",
+						"--manage-token", "streamdal",
 						"--id", tunnelId,
 					)
 					out, err := deleteTunnelCmd.CombinedOutput()
@@ -2840,6 +2868,7 @@ func createKafkaConnection(binary string) string {
 		"create",
 		"connection",
 		"kafka",
+		"--manage-token", "streamdal",
 		"--name", connName,
 		"--address", "localhost:9092",
 	)
@@ -2857,6 +2886,7 @@ func deleteConnection(binary string, connId string) {
 		"manage",
 		"delete",
 		"connection",
+		"--manage-token", "streamdal",
 		"--id", connId,
 	)
 	_, err := deleteConnCmd.CombinedOutput()
@@ -2968,6 +2998,7 @@ func createRabbitConnection(binary string) string {
 		"connection",
 		"rabbit",
 		"--name", connName,
+		"--manage-token", "streamdal",
 		"--address", "amqp://localhost",
 	)
 	out, err := createConnCmd.CombinedOutput()
